==> bibledit-web-0.6.tar.gz: bibledit-web-0.6.1/web/validate/utf8.php <==
<?php


class Validate_Utf8 {

  // Returns true if $str is valid UTF-8 and false otherwise.
  // Note: It seems to fail when validating a book of USFM code.
  private function valid1 ($str)
  {
    // From http://w3.org/International/questions/qa-forms-utf-8.html
    return preg_match('%^(?:
          [\x09\x0A\x0D\x20-\x7E]            # ASCII
        | [\xC2-\xDF][\x80-\xBF]             # non-overlong 2-byte
        |  \xE0[\xA0-\xBF][\x80-\xBF]        # excluding overlongs
        | [\xE1-\xEC\xEE\xEF][\x80-\xBF]{2}  # straight 3-byte
        |  \xED[\x80-\x9F][\x80-\xBF]        # excluding surrogates
        |  \xF0[\x90-\xBF][\x80-\xBF]{2}     # planes 1-3
        | [\xF1-\xF3][\x80-\xBF]{3}          # planes 4-15
        |  \xF4[\x80-\x8F][\x80-\xBF]{2}     # plane 16
    )*$%xs', $str);
  }
  
  // Returns true if $str is valid UTF-8 and false otherwise.
  // Did not work reliably.
  private function valid2 ($str)
  {
    // From www.php.net/manual/en/function.mb-check-encoding.php
    $len = strlen($str); 
    for($i = 0; $i < $len; $i++){ 
        $c = ord($str[$i]); 
        if ($c > 128) { 
            if (($c > 247)) return false; 
            elseif ($c > 239) $bytes = 4; 
            elseif ($c > 223) $bytes = 3; 
            elseif ($c > 191) $bytes = 2; 
            else return false; 
            if (($i + $bytes) > $len) return false; 
            while ($bytes > 1) { 
                $i++; 
                $b = ord($str[$i]); 
                if ($b < 128 || $b > 191) return false; 
                $bytes--; 
            } 
        } 
    } 
    return true; 
  }


  // Returns true if $str is valid UTF-8 and false otherwise.
  public function valid ($str)
  {
    // From www.php.net/manual/en/function.mb-check-encoding.php
    return mb_check_encoding ($str, "UTF-8");
  }

} 


?>

==> bibledit-web-0.9.tar.gz: bibledit-web-0.9/web/validate/utf8.php <==
<?php


class Validate_Utf8 {

  // Returns true if $str is valid UTF-8 and false otherwise.
  // Note: It seems to fail when validating a book of USFM code.
  private static function valid1 ($str)
  {
    // From http://w3.org/International/questions/qa-forms-utf-8.html
    return preg_match('%^(?:
          [\x09\x0A\x0D\x20-\x7E]            # ASCII
        | [\xC2-\xDF][\x80-\xBF]             # non-overlong 2-byte
        |  \xE0[\xA0-\xBF][\x80-\xBF]        # excluding overlongs
        | [\xE1-\xEC\xEE\xEF][\x80-\xBF]{2}  # straight 3-byte
        |  \xED[\x80-\x9F][\x80-\xBF]        # excluding surrogates
        |  \xF0[\x90-\xBF][\x80-\xBF]{2}     # planes 1-3
        | [\xF1-\xF3][\x80-\xBF]{3}          # planes 4-15
        |  \xF4[\x80-\x8F][\x80-\xBF]{2}     # plane 16
    )*$%xs', $str);
  }
  
  // Returns true if $str is valid UTF-8 and false otherwise.
  // Did not work reliably.
  private static function valid2 ($str)
  {
    // From www.php.net/manual/en/function.mb-check-encoding.php
    $len = strlen($str); 
    for($i = 0; $i < $len; $i++){ 
        $c = ord($str[$i]); 
        if ($c > 128) { 
            if (($c > 247)) return false; 
            elseif ($c > 239) $bytes = 4; 
            elseif ($c > 223) $bytes = 3; 
            elseif ($c > 191) $bytes = 2; 
            else return false; 
            if (($i + $bytes) > $len) return false; 
            while ($bytes > 1) { 
                $i++; 
                $b = ord($str[$i]); 
                if ($b < 128 || $b > 191) return false; 
                $bytes--; 
            } 
        } 
    } 
    return true; 
  }


  // Returns true if $str is valid UTF-8 and false otherwise.
  public static function valid ($str)
  {
    // From www.php.net/manual/en/function.mb-check-encoding.php
    return mb_check_encoding ($str, "UTF-8");
  }

} 


?>
